==> alfresco-data-model-23.7.0.13-sources.jar: org/alfresco/repo/tenant/TenantDeployer.java <==
/*
 * #%L
 * Alfresco Data model classes
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.tenant;


/**
 * Tenant Deployer interface.
 * <p>
 * This interface allows components to be notified of tenant events.
 * Components will register with TenantAdminService.
 * Also callbacks used during bootstrap (init) and shutdown (destroy)
 *
 */

public interface TenantDeployer
{    
    public void onEnableTenant();
    
    public void onDisableTenant();
    
    // callback for bootstrap (for each tenant)
    public void init();
    
    // callback for shutdown (for each tenant)
    public void destroy();
}

==> alfresco-data-model-25.3.0.55-sources.jar: org/alfresco/repo/tenant/TenantDeployer.java <==
/*
 * #%L
 * Alfresco Data model classes
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.tenant;

/**
 * Tenant Deployer interface.
 * <p>
 * This interface allows components to be notified of tenant events. Components will register with TenantAdminService. Also callbacks used during bootstrap (init) and shutdown (destroy)
 *
 */

public interface TenantDeployer
{
    public void onEnableTenant();

    public void onDisableTenant();

    // callback for bootstrap (for each tenant)
    public void init();

    // callback for shutdown (for each tenant)
    public void destroy();
}
